diff --git a/doc/src/sgml/mvcc.sgml b/doc/src/sgml/mvcc.sgml
index f88b16e..5002138 100644
--- a/doc/src/sgml/mvcc.sgml
+++ b/doc/src/sgml/mvcc.sgml
@@ -100,6 +100,14 @@
     phenomena caused by interactions?)
    </para>
 
+  <para>
+   The concepts covered in this section are
+   presented without examples of the behaviors described.  The internet,
+   including and espcially the <productname>PostgreSQL</productname> Wiki, is
+   an excellent resource to learn more about circumstances under which these
+   data phenomena occur, and what the results look like when they do.
+  </para>
+
    <para>
     The phenomena which are prohibited at various levels are:
 
@@ -150,12 +158,12 @@
     <indexterm>
      <primary>transaction isolation level</primary>
     </indexterm>
-    The four transaction isolation levels and the corresponding
-    behaviors are described in <xref linkend="mvcc-isolevel-table">.
+    The four SQL transaction isolation levels, and their corresponding
+    behaviors, are described in <xref linkend="mvcc-isolevel-table">.
    </para>
 
     <table tocentry="1" id="mvcc-isolevel-table">
-     <title>Standard <acronym>SQL</acronym> Transaction Isolation Levels</title>
+     <title><acronym>SQL</acronym> Standard Transaction Isolation Levels</title>
      <tgroup cols="4">
       <thead>
        <row>
@@ -256,6 +264,89 @@
    </para>
 
    <para>
+    The three <productname>PostgreSQL</productname> transaction isolation levels, and their corresponding
+    behaviors, are described in <xref linkend="mvcc-pgsql-isolevel-table">.
+   </para>
+
+    <table tocentry="1" id="mvcc-pgsql-isolevel-table">
+     <title><productname>PostgreSQL</productname> Transaction Isolation Levels</title>
+     <tgroup cols="4">
+      <thead>
+       <row>
+        <entry>
+         Isolation Level
+        </entry>
+        <entry>
+         Dirty Read
+        </entry>
+        <entry>
+         Nonrepeatable Read
+        </entry>
+        <entry>
+         Phantom Read
+        </entry>
+       </row>
+      </thead>
+      <tbody>
+       <row>
+        <entry>
+         Read committed
+        </entry>
+        <entry>
+         Not possible
+        </entry>
+        <entry>
+         Possible
+        </entry>
+        <entry>
+         Possible
+        </entry>
+       </row>
+
+       <row>
+        <entry>
+         Repeatable read
+        </entry>
+        <entry>
+         Not possible
+        </entry>
+        <entry>
+         Not possible
+        </entry>
+        <entry>
+         Not Possible
+        </entry>
+       </row>
+
+       <row>
+        <entry>
+         Serializable
+        </entry>
+        <entry>
+         Not possible
+        </entry>
+        <entry>
+         Not possible
+        </entry>
+        <entry>
+         Not possible
+        </entry>
+       </row>
+      </tbody>
+     </tgroup>
+    </table>
+
+   <para>
+    As the table makes clear there is no difference in the potential phenomena
+    at the REPEATABLE READ and SERIALIZABLE transaction isolation levels; but
+    the phenomena listed only pertain to the data seen by the transaction.
+    The difference is that REPEATABLE READ will only serial-fail
+    if two transactions attempt to modify the same record while SERIALIZABLE will 
+    also serial-fail if one transaction modifies a record that another transaction 
+    has only read.
+   </para>
+   
+   <para>
     To set the transaction isolation level of a transaction, use the
     command <xref linkend="sql-set-transaction">.
    </para>
